# Django KTDatatable View

This package is used in conjunction with
the [KTDatatable](https://keenthemes.com/metronic/?page=docs&section=html/components/datatable), and supports
state-saving detection. The package consists of a class-based view, and a small collection of utilities for rendering
table data from [Django](http://www.djangoproject.com/) models.

Dependencies:

* Python 3.8 or later
* [Django](http://www.djangoproject.com/) >= 2.2

# Getting Started

Install the package:

```bash
pip install django-ktdatatable-view
```